==> flutter_1flow_sdk-2023.6.6.tar.gz: lib/flutter_1flow_sdk.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class OneFlow {
  static const MethodChannel methodchannel =
      const MethodChannel('flutter_1flow_sdk');

 
  static Future<void> configure(String projectKey, [bool enableSurveys = true]) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("projectKey", () => projectKey);
     args.putIfAbsent("enableSurveys", () => enableSurveys);
     await methodchannel.invokeMethod('configure',args);
  }

  static Future<void> useFont({String fontFamily = "", String path = ""}) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("fontFamily", () => fontFamily);
     args.putIfAbsent("path", () => path);
     await methodchannel.invokeMethod('useFont',args);
  }

  static Future<void> enableSurveys(bool enableSurveys) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("enableSurveys", () => enableSurveys);
     await methodchannel.invokeMethod('enableSurveys',args);
  }

  static Future<void> logUser(String uniqueId, Object? userDetails) async {
     Map<String,Object> args = <String,Object>{};
     if(userDetails != null){
     args.putIfAbsent("userDetails", () => userDetails);
     }
     args.putIfAbsent("uniqueId", () => uniqueId);
     await methodchannel.invokeMethod('logUser',args);
  }

  static Future<void> recordEventName(String eventName, Object? parameters) async {
     Map<String,Object> args = <String,Object>{};
     if(parameters != null){
      args.putIfAbsent("parameters", () => parameters);
     }
      args.putIfAbsent("eventName", () => eventName);
      print("recordEventName ");
     await methodchannel.invokeMethod('recordEventName',args);
  }

  static Future<String> getSDKVersion() async {
     return "2023.6.6";
  }
}

==> flutter_1flow_sdk-2023.7.20.tar.gz: lib/flutter_1flow_sdk.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class OneFlow {
  static const MethodChannel methodchannel =
      const MethodChannel('flutter_1flow_sdk');

 
  static Future<void> configure(String projectKey, [bool enableSurveys = true]) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("projectKey", () => projectKey);
     args.putIfAbsent("enableSurveys", () => enableSurveys);
     await methodchannel.invokeMethod('configure',args);
  }

  static Future<void> useFont({String fontFamily = "", String path = ""}) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("fontFamily", () => fontFamily);
     args.putIfAbsent("path", () => path);
     await methodchannel.invokeMethod('useFont',args);
  }

  static Future<void> enableSurveys(bool enableSurveys) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("enableSurveys", () => enableSurveys);
     await methodchannel.invokeMethod('enableSurveys',args);
  }

  static Future<void> logUser(String uniqueId, [Object? userDetails]) async {
     Map<String,Object> args = <String,Object>{};
     if(userDetails != null){
     args.putIfAbsent("userDetails", () => userDetails);
     }
     args.putIfAbsent("uniqueId", () => uniqueId);
     await methodchannel.invokeMethod('logUser',args);
  }

  static Future<void> recordEventName(String eventName, [Object? parameters]) async {
     Map<String,Object> args = <String,Object>{};
     if(parameters != null){
      args.putIfAbsent("parameters", () => parameters);
     }
      args.putIfAbsent("eventName", () => eventName);
      print("recordEventName ");
     await methodchannel.invokeMethod('recordEventName',args);
  }



   static Future<void> startFlow(String flowId) async {
     Map<String,Object> args = <String,Object>{};
     args.putIfAbsent("flowId", () => flowId);
      print("startFlow ");
     await methodchannel.invokeMethod('startFlow',args);
  }

  static Future<String> getSDKVersion() async {
     return "2023.6.20";
  }
}
